%%
%% This is file `HFEScon.cls',
%%
%% ----------------------------------------------------------------------
%%
%% HFEScon - A LaTeX class for formatting documents for the HFES Annual Meeting
%%
%% Copyright (C) 2019 by Matthew L. Bolton, mbolton at buffalo.edu, http://fhsl.eng.buffalo.edu/
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License (LPPL), either
%% version 1.3c of this license or (at your option) any later
%% version.  The latest version of this license is in the file:
%%
%% http://www.latex-project.org/lppl.txt
%%
%% Users may freely modify these files without permission, as long as the
%% copyright line and this statement are maintained intact.
%%
%% This work is not endorsed by, affiliated with, or possibly even known
%% by the human factors and ergonomics society.
%%
%% ----------------------------------------------------------------------
%%
\ProvidesClass{HFEScon}[12/21/2019 HFES annual meeting proceedings v1.0, based on APA formatting (6th edition)]
\NeedsTeXFormat{LaTeX2e}

%this class modifies the apa6's journal class
\LoadClass[jou,natbib]{apa6}

\RequirePackage[american]{babel}

\RequirePackage[font=small,skip=0pt]{caption}

\AtBeginDocument{\renewcommand{\bibsection}{\section\refname}}
\AtBeginDocument{\pagenumbering{gobble}}

%this is stuff for reformatting the the sectioning
\let\apasubparagraph\subparagraph
\let\subparagraph\paragraph
\RequirePackage[compact]{titlesec}
\let\subparagraph\apasubparagraph
\newcommand{\addperiod}[1]{#1.~~}
\titleformat*{\section}{\centering\normalsize\bfseries\MakeUppercase}
\titleformat*{\subsection}{\normalsize\bfseries}
\titleformat{\subsubsection}[runin]{\normalsize\em}{\thesubsection}{0em}{\addperiod}
\titlespacing*{\subsubsection}{\parindent}{0pt}{0pt}

%this changes paragraph indentation
\setlength\parindent{0.25in}
\setlength\bibhang{\parindent}

%these are commands for recreating the behavior of apacite with natbib
\renewcommand{\cite}[1]{\citep{#1}}
\newcommand{\citeA}[1]{\citet{#1}}
\newcommand{\citeNP}[1]{\citealt{#1}}

%redefine footnotesize to 8pt font
\renewcommand{\footnotesize}{\fontsize{8pt}{9.6pt}\selectfont}

%set the bibliography to the right font size
\def\bibfont{\footnotesize}

%format the captions and float separation
\captionsetup[figure]{font=footnotesize,belowskip=0pt,aboveskip=5pt}
\captionsetup[table]{font=footnotesize,labelsep = period}
\setlength{\textfloatsep}{10pt plus 1.0pt minus 2.0pt}


\let\oldtitle\title
\renewcommand{\title}[1]{\oldtitle{\vspace{-10pt}\textbf{\large #1}}}

\let\oldauthor\author
\renewcommand{\author}[1]{\oldauthor{\normalsize#1}}

\let\oldtwoauthors\twoauthors
\renewcommand{\twoauthors}[2]{\oldtwoauthors{\normalsize#1}{\normalsize#2}}

\let\oldthreeauthors\threeauthors
\renewcommand{\threeauthors}[3]{\oldthreeauthors{\normalsize#1}{\normalsize#2}{\normalsize#3}}
\let\oldfourauthors\fourauthors

\renewcommand{\fourauthors}[4]{\oldfourauthors{\normalsize#1}{\normalsize#2}{\normalsize#3}{\normalsize#4}}
\let\oldfiveauthors\fiveauthors

\renewcommand{\fiveauthors}[5]{\oldfiveauthors{\normalsize#1}{\normalsize#2}{\normalsize#3}{\normalsize#4}{\normalsize#5}}
\let\oldsixauthors\sixauthors

\renewcommand{\sixauthors}[6]{\oldsixauthors{\normalsize#1}{\normalsize#2}{\normalsize#3}{\normalsize#4}{\normalsize#5}{\normalsize#6}}


\let\oldaffiliation\affiliation
\renewcommand{\affiliation}[1]{\oldaffiliation{\normalsize#1\vspace{-10pt}}}

\let\oldthreeaffiliations\threeaffiliations
\renewcommand{\threeaffiliations}[3]{\oldthreeaffiliations{\normalsize#1\vspace{-10pt}}{\normalsize#2\vspace{-10pt}}{\normalsize#3\vspace{-10pt}}}

\let\oldfouraffiliations\fouraffiliations
\renewcommand{\fouraffiliations}[4]{\oldfouraffiliations{\normalsize#1}{\normalsize#2}{\normalsize#3\vspace{-10pt}}{\normalsize#4\vspace{-10pt}}}

\let\oldfiveaffiliations\fiveaffiliations
\renewcommand{\fiveaffiliations}[5]{\oldfiveaffiliations
{\normalsize#1}
{\normalsize#2}
{\normalsize#3\vspace{-10pt}}
{\normalsize#4\vspace{-10pt}}
{\normalsize#5\vspace{-10pt}}}

\let\oldsixaffiliations\sixaffiliations
\renewcommand{\sixaffiliations}[6]{\oldsixaffiliations
{\normalsize#1}
{\normalsize#2}
{\normalsize#3}
{\normalsize#4}
{\normalsize#5\vspace{-10pt}}
{\normalsize#6\vspace{-10pt}}}

\let\oldabstract\abstract
\renewcommand{\abstract}[1]{\oldabstract{\newgeometry{margin=1.25in}\normalsize #1\vspace{-12pt}}}

\leftheader{ }
\rightheader{ }
\newgeometry{left=0.5in,right=0.5in,bottom=0.5in,top=1in,columnsep=0.5in}
\pagestyle{empty}

\makeatletter
\renewenvironment{table}{%
  \renewcommand* {\@floatboxreset}{\reset@font\@setminipage}
  \footnotesize\@float{table}}{\end@float}
\makeatother

%% End of file `HFEScon.cls'.
